@@ -220,7 +220,8 @@ class TextureVisuals(Visuals):
         concatenated : TextureVisuals
           Concatenated visual objects
         """
-        util.log.warning('concatenating texture: may result in visual artifacts')
+        util.log.warning(
+            'concatenating texture: may result in visual artifacts')
         from .objects import concatenate
         return concatenate(self, others)
 
